@@ -1,8 +1,14 @@
+# base
 from .base.kd_compose_transform import KDComposeTransform
 from .base.kd_transform import KDTransform
+# augs
 from .image_pos_embed_grid import ImagePosEmbedGrid
 from .image_pos_embed_sincos import ImagePosEmbedSincos
-from .image_range_norm import ImageRangeNorm
+# norm
+from .norm.kd_cifar10_norm import KDCifar10Norm
+from .norm.kd_image_net_norm import KDImageNetNorm
+from .norm.kd_image_norm import KDImageNorm
+from .norm.kd_image_range_norm import KDImageRangeNorm
 from .patchify_image import PatchifyImage
 from .patchwise_random_rotation import PatchwiseRandomRotation
 from .unpatchify_image import UnpatchifyImage
